==> wm-react-native-components-0.0.70.tgz: package/refreshscrollview/RefreshScrollView.js <==
/**
 * Created with IntelliJ IDEA.
 * User: aaronlin
 * Date: 2018/7/11
 * Time: 16:55
 */
import React, {Component} from 'react';

import {
    ScrollView,
    Platform,
} from 'react-native';

import PropTypes from 'prop-types';

import PullToRefreshContainerV2 from '../pulltorefresh/PullToRefreshContainerV2';

/**
 * 下拉刷新 ScrollView
 */
export default class RefreshScrollView extends Component{

    /**
     *
     * @type {{useRefreshViewDefault: React$PropType$Primitive.<boolean>, enabledPullDown: React$PropType$Primitive.<boolean>, enabledPullUp: React$PropType$Primitive.<boolean>, onRefresh, onLoadMore}}
     */
    static propTypes = {
        enabledPullDown:PropTypes.bool,		//是否开启下拉刷新
    }

    /**
     *
     * @type {{enabledPullDown: boolean, enabledPullUp: boolean}}
     */
    static defaultProps = {
        enabledPullDown: true,
    }

    /**
     *
     */
    _scrollY = 0;

    constructor(props){
        super(props);
    }

    /**
     *
     * @param event
     * @private
     */
    _onScroll = (e) => {
        this._scrollY = e.nativeEvent.contentOffset.y;

        const{ onScroll } = this.props;
        onScroll && onScroll(e);
    }

    /**
     *
     * @param evt
     * @param gestureState
     * @returns {boolean}
     * @private
     */
    _isReadyForPullStart = (evt, gestureState)=>{
        const { dx, dy } = gestureState;
        if(this._scrollY <= 0){
            return dy > 0;
        }
    }

    /**
     * 刷新结束
     */
    endRefreshing = () => {
        this.refs.pullToRefreshContainer && this.refs.pullToRefreshContainer.endRefreshing();
    }

    render(){
        const { enabledPullDown, pullContainerStyle, headerStyle, onRefresh, ...otherProps } = this.props;

        //
        const refreshControl = (
            <PullToRefreshContainerV2
                ref={'pullToRefreshContainer'}
                isReadyForPullStart={this._isReadyForPullStart}
                style={[styles.container, pullContainerStyle]}
                headerStyle={[headerStyle]}
                onRefresh={onRefresh}
            />
        );

        const scrollView = (
            <ScrollView
                {...otherProps}
                onScroll={this._onScroll}
                noInterceptTouchConfig={{y:'>=3', isTop:true}}
            />
        );

        if(enabledPullDown){    //下拉刷新
            return React.cloneElement(refreshControl, null, scrollView);
        }

        return scrollView;
    }

}

const styles = {
    container: {
        flex: 1,
        backgroundColor: "#ffffff"
    }
};

==> wm-react-native-components-0.0.91.tgz: package/refreshscrollview/RefreshScrollView.js <==
/**
 * Created with IntelliJ IDEA.
 * User: aaronlin
 * Date: 2018/7/11
 * Time: 16:55
 */
import React, {Component} from 'react';

import {
    ScrollView,
    Platform,
} from 'react-native';

import PropTypes from 'prop-types';

import PullToRefreshContainerV2 from '../pulltorefresh/PullToRefreshContainerV2';

/**
 * 下拉刷新 ScrollView
 */
export default class RefreshScrollView extends Component{

    /**
     *
     * @type {{useRefreshViewDefault: React$PropType$Primitive.<boolean>, enabledPullDown: React$PropType$Primitive.<boolean>, enabledPullUp: React$PropType$Primitive.<boolean>, onRefresh, onLoadMore}}
     */
    static propTypes = {
        enabledPullDown:PropTypes.bool,		//是否开启下拉刷新
    }

    /**
     *
     * @type {{enabledPullDown: boolean, enabledPullUp: boolean}}
     */
    static defaultProps = {
        enabledPullDown: true,
    }

    /**
     *
     */
    _scrollY = 0;

    constructor(props){
        super(props);
    }

    /**
     *
     * @param event
     * @private
     */
    _onScroll = (e) => {
        this._scrollY = e.nativeEvent.contentOffset.y;

        const{ onScroll } = this.props;
        onScroll && onScroll(e);
    }

    /**
     *
     * @param evt
     * @param gestureState
     * @returns {boolean}
     * @private
     */
    _isReadyForPullStart = (evt, gestureState)=>{
        const { dx, dy } = gestureState;
        if(this._scrollY <= 0){
            return dy > 0;
        }
    }

    /**
     * 刷新结束
     */
    endRefreshing = () => {
        this.refs.pullToRefreshContainer && this.refs.pullToRefreshContainer.endRefreshing();
    }

    render(){
        const { enabledPullDown, pullContainerStyle, headerStyle, onRefresh, ...otherProps } = this.props;

        //
        const refreshControl = (
            <PullToRefreshContainerV2
                ref={'pullToRefreshContainer'}
                isReadyForPullStart={this._isReadyForPullStart}
                style={[styles.container, pullContainerStyle]}
                headerStyle={[headerStyle]}
                onRefresh={onRefresh}
            />
        );

        const scrollView = (
            <ScrollView
                noInterceptTouchConfig={{y:'>=3', isTop:true, x:'<=-5||>=3'}}
                {...otherProps}
                onScroll={this._onScroll}
            />
        );

        if(enabledPullDown){    //下拉刷新
            return React.cloneElement(refreshControl, null, scrollView);
        }

        return scrollView;
    }

}

const styles = {
    container: {
        flex: 1,
        backgroundColor: "#ffffff"
    }
};
